<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Dokter;

class DokterController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(!\Helper::hakAkses('Terapis','View')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }
        
        $title = "Terapis";
        $url = "dokter";
        $menu = "Dokter";

        $dokter = Dokter::all();
        return view('dokter.index', compact('title', 'url', 'menu', 'dokter'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(!\Helper::hakAkses('Terapis','Create')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }

        $title = "Terapis";
        $url = "dokter";
        $menu = "Dokter";

        return view('dokter.create', compact('title', 'url', 'menu'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        
        if(!\Helper::hakAkses('Terapis','Create')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }
        
        $this->validate($request, [
            'nama_dokter' => 'required',
            'alamat' => 'required',
            'no_hp' => 'required',
        ]);
            
        try {
        $dokter = Dokter::create([
            'nama_dokter' => $request->nama_dokter,
            'alamat' => $request->alamat,
            'no_hp' => $request->no_hp,
        ]);

        \Helper::addUserLog('menambah data Dokter '.$request->nama_dokter,$dokter->toArray());

        return redirect()->route('dokter.index')->with('success', 'Data Berhasil Ditambahkan');

        } catch (\Throwable $th) {
            return redirect()->back()->with('error', 'Ada Masalah, ' . $th->getMessage())->withInput();
        }

    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {

    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(!\Helper::hakAkses('Terapis','Update')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }
        
        $dokter = Dokter::find($id);
        $title = "Terapis";
        $url = "dokter";
        $menu = "Dokter";
        
        return view('dokter.edit', compact('title', 'url', 'menu', 'dokter'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        if(!\Helper::hakAkses('Terapis','Update')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }

        try {
            $dokter = Dokter::find($id);
            $old = $dokter->toArray();
            $dokter->update([
                'nama_dokter' => $request->nama_dokter,
                'alamat' => $request->alamat,
                'no_hp' => $request->no_hp,
            ]);

            \Helper::addUserLog('Mengubah Data Dokter '.$request->nama_dokter,[
                'old'=>$old,
                'update'=>$dokter->toArray()
            ]);

            return redirect(route('dokter.index'))->with('success', 'Data Berhasil Diubah');
        } catch (\Throwable $th) {
            return redirect()->back()->with('error', 'Ada Masalah, ' . $th->getMessage())->withInput();
        }

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        if(!\Helper::hakAkses('Terapis','Delete')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }

        try {    
            $dokter = Dokter::find($id);            
            $nama = $dokter->nama_dokter;
            $dokter->delete();
            \Helper::addUserLog('Menghapus Data Dokter '.$nama,$dokter->toArray());        
           
        } catch (\Throwable $th) {
            return redirect()->back()->with('error', 'Ada Masalah, ' . $th->getMessage())->withInput();
        }

        return redirect(route('dokter.index'))->with('success', 'Data Berhasil Dihapus');
    }
}
